@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -26,8 +26,7 @@
 #include <QString>
 #include <QMap>
 
-namespace KContacts
-{
+namespace KContacts {
 class KCONTACTS_EXPORT Related
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Related &);
@@ -42,19 +41,19 @@ public:
     typedef QVector<Related> List;
 
     void setRelated(const QString &relatedTo);
-    QString related() const;
+    Q_REQUIRED_RESULT QString related() const;
 
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
     void setParameters(const QMap<QString, QStringList> &params);
-    QMap<QString, QStringList> parameters() const;
+    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
 
-    bool operator==(const Related &other) const;
-    bool operator!=(const Related &other) const;
+    Q_REQUIRED_RESULT bool operator==(const Related &other) const;
+    Q_REQUIRED_RESULT bool operator!=(const Related &other) const;
 
     Related &operator=(const Related &other);
 
-    QString toString() const;
+    Q_REQUIRED_RESULT QString toString() const;
 private:
     class Private;
     QSharedDataPointer<Private> d;
@@ -62,7 +61,6 @@ private:
 KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Related &object);
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Related &object);
-
 }
 Q_DECLARE_TYPEINFO(KContacts::Related, Q_MOVABLE_TYPE);
 #endif // LANG_H
